#! /usr/bin/env python

from os.path import splitext
import re
import sys

def tokenize(lines):
    regex = re.compile(r"([()]|\s+|;.*)")
    for line in lines:
        for token in regex.split(line):
            yield token

def process_pddl_file(filename, forbidden_tokens=[], forbidden_structures=[]):
    result = []
    token_iterator = tokenize(open(filename))
    for token in token_iterator:
        if token in forbidden_structures:
            try:
                while result[-1].isspace():
                    result.pop()
                if result.pop() != "(":
                    raise ValueError
            except (IndexError, ValueError):
                raise SystemExit("bad PDDL in file %r" % filename)
            paren_counter = 1
            balance = {"(": +1, ")": -1}
            for skip_token in token_iterator:
                paren_counter += balance.get(skip_token, 0)
                if paren_counter == 0:
                    break
        elif token not in forbidden_tokens:
            result.append(token)

    outfile = open(splitext(filename)[0] + "-woac.pddl", "w")
    outfile.write("".join(result))


if len(sys.argv) != 3:
    raise SystemExit("Usage: %s <DOMAINFILE> <PROBLEMFILE>" % sys.argv[0])

process_pddl_file(sys.argv[1], forbidden_tokens=[":action-costs"],
                  forbidden_structures=[":functions", "increase"])
process_pddl_file(sys.argv[2], forbidden_structures=["=", ":metric"])
